package com.ruoyi.project.configuration.service;

import java.util.List;
import com.ruoyi.project.configuration.domain.TStaffmgr;

/**
 * 人员信息Service接口
 * 
 * @author ruoyi
 * @date 2022-01-11
 */
public interface ITStaffmgrService 
{
    /**
     * 查询人员信息
     * 
     * @param id 人员信息ID
     * @return 人员信息
     */
    public TStaffmgr selectTStaffmgrById(Long id);

    /**
     * 查询人员信息
     *
     * @param staffId 人员信息IC卡号
     * @return 人员信息
     */
    public TStaffmgr selectTStaffmgrByIc(String staffId);

    /**
     * 查询人员信息列表
     * 
     * @param tStaffmgr 人员信息
     * @return 人员信息集合
     */
    public List<TStaffmgr> selectTStaffmgrList(TStaffmgr tStaffmgr);

    /**
     * 新增人员信息
     * 
     * @param tStaffmgr 人员信息
     * @return 结果
     */
    public int insertTStaffmgr(TStaffmgr tStaffmgr);

    /**
     * 修改人员信息
     * 
     * @param tStaffmgr 人员信息
     * @return 结果
     */
    public int updateTStaffmgr(TStaffmgr tStaffmgr);

    /**
     * 批量删除人员信息
     * 
     * @param ids 需要删除的人员信息ID
     * @return 结果
     */
    public int deleteTStaffmgrByIds(Long[] ids);

    /**
     * 删除人员信息信息
     * 
     * @param id 人员信息ID
     * @return 结果
     */
    public int deleteTStaffmgrById(Long id);
}
